@@ -3,24 +3,18 @@
 #' @description A function that calculates variance upper bounds
 #'
 #' @param estimates an object returned from `get_est()` function
-#' @param bound_est an integer specifying the estimator for the asymptotic variance bound. Use `1` for the first estimator and `2` for the second estimator.Default is `1`. See details.
 #' 
 #' @returns list of variance upper bounds for each scenario (`bound_haj`) and causal contrasts (`bound_tau_haj`). 
 #' Note that this function returns variance upper bounds for Hajek estimators
 #'  
 #' @details `get_var_bound()` is an internal function to `get_estimates()` function, 
-#' performing the estimation analysis after `get_est()` function. There are two consistent
-#'  estimators for the asymptotic variance bound. The first estimator (default, `bound_est=1`) 
-#'  performs well in scenarios with low variability, but exhibit some under coverage issue for high
-#'  variability scenarios where longer time series are needed for getting robust estimator. The second 
-#'  estimator(`bound_est=2`) yields good coverage rates in simulations, but gives unreasonably large bound when there 
-#'  'are extremely large IPW weights.  Users should carefully consider the  
-#'  characteristics of their data when selecting the estimator. 
+#' performing the estimation analysis after `get_est()` function. 
 
-get_var_bound <- function(estimates, bound_est = 1) {
+get_var_bound <- function(estimates) {
   
   # Define arguments
   weights <- estimates$weights
+  stabilizer <- estimates$stabilizer
   B <- estimates$windows
   smoothed_outcome <- estimates$smoothed_outcome
   num_interv <- dim(weights)[1]
@@ -50,7 +44,7 @@ get_var_bound <- function(estimates, bound_est = 1) {
 
   rownames(bound) <- paste0("cf_", 1 : num_interv)
   
-  # Bound for tau
+  # Bound for tau (IPW)
   bound_t <- array(NA, dim = c(num_interv, num_interv, num_B))
   for (ii in 1 : (num_interv - 1)) {
     for (jj in (ii + 1) : num_interv) {
@@ -59,22 +53,11 @@ get_var_bound <- function(estimates, bound_est = 1) {
     }
   }
   
-  # Bound for Hajek
+  # Variance upper bound (Hajek)
   mean_weight <- apply(weights, 1, mean)
   all_est <- sweep(all_est, MARGIN = 1, mean_weight, FUN = '/')
-  if(bound_est==1){
-    weights <- sweep(weights, MARGIN = 1, mean_weight, FUN = '/')
-  }
-
-
-  # bound_haj <- sweep(bound, 1, mean_weight ^ 2, FUN = '/')     # ad hoc approach
-  # bound_t_haj <- array(NA, dim = c(num_interv, num_interv, num_B))
-  # for (ii in 1 : (num_interv - 1)) {
-  #   for (jj in (ii + 1) : num_interv) {
-  #     est <- all_est[ii, , , drop = FALSE] - all_est[jj, , , drop = FALSE]
-  #     bound_t_haj[ii, jj, ] <- apply(est, 3, function(x) mean(x ^ 2) / num_time_points)
-  #   }
-  # }
+  weights <- sweep(weights, MARGIN = 1, stabilizer, FUN = '/')
+  
   
   bound_haj <- array(NA,c(num_interv,num_B))
   rownames(bound_haj) <- paste0("cf_", 1 : num_interv)
@@ -88,7 +71,7 @@ get_var_bound <- function(estimates, bound_est = 1) {
     
   }
   
-  # Bound for tau and Hajek
+  # Bound for tau (Hajek)
   bound_t_haj <- array(NA, dim = c(num_interv, num_interv, num_B))
   for (ii in 1 : (num_interv - 1)) {
     for (jj in (ii + 1) : num_interv) {
